@@ -11,7 +11,6 @@
 #define __LIBXMLPP_OSTREAMOUTPUTBUFFER_H
 
 #include <libxml++/io/outputbuffer.h>
-#include <libxml++/api_export.h>
 
 #include <ostream>
 
@@ -19,7 +18,7 @@ namespace xmlpp
 {
   /** An OutputBuffer implementation that send datas to a std::ostream.
    */
-  class LIBXMLPP_API OStreamOutputBuffer: public OutputBuffer
+  class OStreamOutputBuffer: public OutputBuffer
   {
     public:
       /**
@@ -27,7 +26,7 @@ namespace xmlpp
        * @param encoding Charset in which data will be encoded before being
        * sent to the stream
        */
-      OStreamOutputBuffer(std::ostream& output, const std::string& encoding = std::string());
+      OStreamOutputBuffer(std::ostream& output, const Glib::ustring& encoding = Glib::ustring());
       virtual ~OStreamOutputBuffer();
 
     private:
@@ -36,6 +35,6 @@ namespace xmlpp
 
       std::ostream& output_;
   };
-};
+}
 
 #endif
